@@ -66,7 +66,7 @@ public:
   virtual bool handleMessage(XEvent *E,Message *msg);
   bool getShowDual() const;
   void setShowDual(bool);
-  int setFont(char*);
+  int setFont( const char* );
   virtual const char *getType() const;
   virtual bool isType(const char *type) const;
 
