@@ -1,6 +1,6 @@
 /* choosebutton.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2005,2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* $Id: choosebutton.cc,v 1.27 2005/10/06 20:03:28 ralf Exp $ */
 
 #include "choosebutton.h"
 #include "awindow.h"
@@ -373,7 +372,7 @@ void ChooseButton::updateWin()
   }
 }
 
-int ChooseButton::setFont(char *fontname)
+int ChooseButton::setFont( const char *fontname )
 {
   font=_aguix->getFont(fontname);
   if(font==NULL) return -1;
