@@ -1,6 +1,6 @@
 /* cyclebutton.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2007,2009 Ralf Hoffmann.
+ * Copyright (C) 2001-2007,2009-2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -378,7 +378,7 @@ bool CycleButton::handleMessage(XEvent *E,Message *msg)
                  // this message (f.e. StringGagdet for deactivating)
 }
 
-int CycleButton::setFont(char *fontname)
+int CycleButton::setFont( const char *fontname )
 {
   font=_aguix->getFont(fontname);
   if(font==NULL) return -1;
