@@ -1,6 +1,6 @@
 /* fieldlistview.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2009 Ralf Hoffmann.
+ * Copyright (C) 2002-2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -374,6 +374,11 @@ void FieldListView::checkShrink()
   }
 }
 
+int FieldListView::getNrOfFields() const
+{
+    return fields;
+}
+
 void FieldListView::setNrOfFields( int nv )
 {
   int *nw, *nu, i, *nmr;
@@ -2211,7 +2216,7 @@ void FieldListView::setupBars()
   }
 }
 
-int FieldListView::setFont(char *fontname)
+int FieldListView::setFont( const char *fontname )
 {
   font=_aguix->getFont(fontname);
   if(font==NULL) return -1;
