@@ -1,6 +1,6 @@
 /* configtokens.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2003-2010 Ralf Hoffmann.
+ * Copyright (C) 2003-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -110,6 +110,7 @@ struct mytoken tokenlist[]={
   {BUTTONFONT_WCP,"buttonfont"},
   {LEFTFONT_WCP,"leftfont"},
   {RIGHTFONT_WCP,"rightfont"},
+  {TEXTVIEWFONT_WCP,"textviewfont"},
   {CLOCKBARSETS_WCP,"clockbarsets"},
   {MODUS_WCP,"modus"},
   {TIMESPACE_WCP,"timespace"},
@@ -370,7 +371,21 @@ struct mytoken tokenlist[]={
   { PARTFILE_WCP, "partfile" },
   { REQUESTACTION_WCP, "requestaction" },
   { WEIGHTTOACTIVE_WCP, "weighttoactive" },
-  { SIZEH_WCP, "sizeh" }
+  { SIZEH_WCP, "sizeh" },
+  { NEXTAGING_WCP, "nextaging" },
+  { ENTRY_WCP, "entry" },
+  { PREFIX_WCP, "prefix" },
+  { VALUE_WCP, "value" },
+  { EJECTCOMMAND_WCP, "ejectcommand" },
+  { CLOSETRAYCOMMAND_WCP, "closetraycommand" },
+  { AVFSMODULE_WCP, "avfsmodule" },
+  { FLEXIBLEMATCH_WCP, "flexiblematch" },
+  { USE_VERSION_STRING_COMPARE_WCP, "useversionstringcompare" },
+  { SWITCHBUTTONBANKOP_WCP, "switchbuttonbankop" },
+  { SWITCHTONEXTBANK_WCP, "switchtonextbank" },
+  { SWITCHTOPREVBANK_WCP, "switchtoprevbank" },
+  { SWITCHTOBANKNR_WCP, "switchtobanknr" },
+  { BANKNR_WCP, "banknr" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
