@@ -1,6 +1,6 @@
 /* createsymlinkop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2008 Ralf Hoffmann.
+ * Copyright (C) 2001-2004,2008,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,6 +24,11 @@
 #include "normalmode.h"
 #include "worker.h"
 #include "nmspecialsourceext.hh"
+#include "datei.h"
+#include "dnd.h"
+#include "worker_locale.h"
+#include <aguix/button.h>
+#include <aguix/choosebutton.h>
 
 const char *CreateSymlinkOp::name="CreateSymlinkOp";
 
@@ -33,6 +38,7 @@ CreateSymlinkOp::CreateSymlinkOp() : FunctionProto()
   local=false;
   requestflags=false;
   hasConfigure = true;
+    m_category = FunctionProto::CAT_FILEOPS;
 }
 
 CreateSymlinkOp::~CreateSymlinkOp()
