@@ -1,6 +1,6 @@
 /* datei.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008,2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2008,2010-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -23,9 +23,10 @@
 #define DATEI_H
 
 #include "wdefines.h"
-#include <aguix/awidth.h>
 #include <string>
 
+class AWidth;
+
 class Datei
 {
 public:
@@ -104,3 +105,6 @@ char *resolveEnv(const char*);
 
 #endif
 
+/* Local Variables: */
+/* mode:c++ */
+/* End: */
