@@ -34,6 +34,8 @@
 #include "bookmarkdbproxy.hh"
 #include "nwc_path.hh"
 #include <algorithm>
+#include "prefixdb.hh"
+#include "worker.h"
 
 DirBookmarkUI::DirBookmarkUI( AGUIX &aguix, BookmarkDBProxy &data  ) : m_aguix( aguix ),
                                                                        m_data( data )
@@ -161,6 +163,15 @@ int DirBookmarkUI::mainLoop()
     AGMessage *msg;
     int endmode = 0;
 
+    std::string cfgfile = Worker::getWorkerConfigDir();
+#ifdef USEOWNCONFIGFILES
+    cfgfile = NWC::Path::join( cfgfile, "prefix.db2" );
+#else
+    cfgfile = NWC::Path::join( cfgfile, "prefix.db" );
+#endif
+
+    PrefixDB pdb( cfgfile );
+
     updateCategoryText( current_cat );
 
     {
@@ -302,6 +313,7 @@ int DirBookmarkUI::mainLoop()
                       if ( KEYSTATEMASK( msg->key.keystate ) == ShiftMask ) {
                           m_filtered_data->setInfixFilter( "" );
                           showData( current_cat );
+			  highlightBestHit( pdb );
                       } else {
                           std::string cur_infix = m_filtered_data->getInfixFilter();
                           
@@ -309,6 +321,7 @@ int DirBookmarkUI::mainLoop()
                               cur_infix.resize( cur_infix.length() - 1 );
                               m_filtered_data->setInfixFilter( cur_infix );
                               showData( current_cat );
+			      highlightBestHit( pdb );
                           }
                       }
                   } else if ( msg->key.key == XK_Return ) {
@@ -318,10 +331,12 @@ int DirBookmarkUI::mainLoop()
                   } else if ( msg->key.key == XK_Left ) {
                       current_cat = switchCat( current_cat, -1 );
                       showData( current_cat );
+		      highlightBestHit( pdb );
                       updateCategoryText( current_cat );
                   } else if ( msg->key.key == XK_Right ) {
                       current_cat = switchCat( current_cat, 1 );
                       showData( current_cat );
+		      highlightBestHit( pdb );
                       updateCategoryText( current_cat );
                   } else if ( msg->key.key == XK_Up ) {
                   } else if ( msg->key.key == XK_Down ) {
@@ -344,6 +359,7 @@ int DirBookmarkUI::mainLoop()
                           m_filtered_data->setInfixFilter( old_infix );
                       }
                       showData( current_cat );
+		      highlightBestHit( pdb );
                   }
                   break;
               case AG_FIELDLV_DOUBLECLICK:
@@ -405,6 +421,7 @@ int DirBookmarkUI::mainLoop()
                   it1++, row-- ) {
                 if ( row == 0 ) {
                     m_selected_entry = std::auto_ptr<BookmarkDBEntry>( new BookmarkDBEntry( *it1 ) );
+		    pdb.pushAccess( m_filtered_data->getInfixFilter(), it1->getName() );
                 }
             }
         }
@@ -568,3 +585,23 @@ void DirBookmarkUI::maximizeWin()
     }
     m_win->contMaximize( true );
 }
+
+void DirBookmarkUI::highlightBestHit( class PrefixDB &pdb )
+{
+    if ( m_filtered_data->getInfixFilter().empty() ) return;
+
+    std::string best_hit = pdb.getBestHit( m_filtered_data->getInfixFilter() );
+
+    if ( best_hit.empty() ) return;
+
+    // search for best_hit in visible entries
+
+    for ( int row = 0;; row++ ) {
+	if ( m_lv->isValidRow( row ) == false ) break;
+	if ( m_lv->getText( row, 0 ) == best_hit ) {
+	    m_lv->setActiveRow( row );
+	    m_lv->showActive();
+	    break;
+	}
+    }
+}
