@@ -1,6 +1,6 @@
 /* ownop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2005,2008,2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2005,2008,2010-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,6 +25,14 @@
 #include "worker.h"
 #include "filereq.h"
 #include "nmspecialsourceext.hh"
+#include "datei.h"
+#include <aguix/button.h>
+#include <aguix/fieldlistview.h>
+#include <aguix/stringgadget.h>
+#include <aguix/cyclebutton.h>
+#include <aguix/choosebutton.h>
+#include "worker_locale.h"
+#include "dnd.h"
 
 const char *OwnOp::name="OwnOp";
 
