@@ -1,6 +1,6 @@
 /* ownop.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2005,2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2005,2010-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,12 +24,6 @@
 
 #include "wdefines.h"
 #include "functionproto.h"
-#include <aguix/awindow.h>
-#include <aguix/text.h>
-#include <aguix/solidbutton.h>
-#include <aguix/button.h>
-#include <aguix/cyclebutton.h>
-#include <aguix/stringgadget.h>
 
 class Worker;
 
