@@ -23,6 +23,21 @@
 #include "fileviewer.hh"
 #include "worker.h"
 
+class PEA_FileView_Destroyer : public FileViewerDestroyCallback
+{
+public:
+    PEA_FileView_Destroyer( const std::string &filename ) : m_filename( filename )
+    {}
+    ~PEA_FileView_Destroyer()
+    {
+	if ( ! m_filename.empty() ) {
+	    worker_unlink( m_filename.c_str() );
+	}
+    }
+private:
+    std::string m_filename;
+};
+
 ProcessExitAction::ProcessExitAction( bool show_file,
                                       const std::string &tmp_name,
                                       Worker *worker ) : m_show_file( show_file ),
@@ -31,8 +46,12 @@ ProcessExitAction::ProcessExitAction( bool show_file,
 {
 }
 
-void ProcessExitAction::callback()
+void ProcessExitAction::callback( int status )
 {
+    if ( m_worker != NULL && status != 0 ) {
+        m_worker->showCommandFailed( status );
+    }
+
     if ( m_show_file == true &&
          ! m_tmp_name.empty() &&
          m_worker != NULL ) {
@@ -40,12 +59,8 @@ void ProcessExitAction::callback()
         l.push_back( m_tmp_name );
         
         FileViewer fv;
-        m_worker->setWaitCursor();
-        fv.view( l );
-        m_worker->unsetWaitCursor();
-    }
+	RefCount< PEA_FileView_Destroyer > cb = new PEA_FileView_Destroyer( m_tmp_name );
 
-    if ( ! m_tmp_name.empty() ) {
-        worker_unlink( m_tmp_name.c_str() );
+        fv.view( l, cb );
     }
 }
