@@ -1,6 +1,6 @@
 /* searchop.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006-2008 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2006-2008,2010-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -32,7 +32,13 @@
 #include <typeinfo>
 #include "filenameshrinker.hh"
 #include <aguix/kartei.h>
+#include <aguix/stringgadget.h>
+#include <aguix/choosebutton.h>
+#include <aguix/button.h>
 #include "calendar.hh"
+#include "worker_locale.h"
+#include "wconfig.h"
+#include "datei.h"
 
 const char *SearchOp::name = "SearchOp";
 std::list<SearchOp::ResultStore*> SearchOp::_stored_results;
@@ -69,6 +75,7 @@ SearchOp::SearchOp() : FunctionProto(),
                        m_size_geq_sg( NULL ),
                        m_size_leq_sg( NULL ),
                        m_options_k1( NULL ),
+                       m_max_vfs_depth_sg( NULL ),
                        _search_started( false )
 {
   _edit_command = DEFAULT_EDIT_COMMAND;
@@ -232,7 +239,7 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
   m_options_k1->add( subwin2 );
   subwin2->create();
 
-  AContainer *acsw2_1 = subwin2->setContainer( new AContainer( subwin2, 1, 2 ), true );
+  AContainer *acsw2_1 = subwin2->setContainer( new AContainer( subwin2, 1, 3 ), true );
   acsw2_1->setMinSpace( 5 );
   acsw2_1->setMaxSpace( 5 );
   acsw2_1->setBorderWidth( 5 );
@@ -264,6 +271,15 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
   m_size_leq_sg = (StringGadget*)acsub2->add( new StringGadget( aguix, 0, 0, 100, "", 0 ), 3, 0, AContainer::CO_INCW );
   Button *size_help_b = (Button*)acsub2->add( new Button( aguix, 0, 0, catalog.getLocale( 483 ), 1, 0, 0 ), 4, 0, AContainer::CO_FIX );
 
+  AContainer *acsub3 = acsw2_1->add( new AContainer( subwin2, 3, 1 ), 0, 2 );
+  acsub3->setMinSpace( 5 );
+  acsub3->setMaxSpace( 5 );
+  acsub3->setBorderWidth( 0 );
+
+  acsub3->add( new Text( aguix, 0, 0, catalog.getLocale( 940 ), 1 ), 0, 0, AContainer::CO_FIX );
+  m_max_vfs_depth_sg = (StringGadget*)acsub3->add( new StringGadget( aguix, 0, 0, aguix->getTextWidth( "MMMMMMMMM" ), "3", 0 ),
+                                                   1, 0, AContainer::CO_FIX );
+
   m_options_k1->setOption( subwin1, 0, catalog.getLocale( 815 ) );
   m_options_k1->setOption( subwin2, 1, catalog.getLocale( 816 ) );
   m_options_k1->maximize();
@@ -424,7 +440,7 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
   int update_ctr = 0;
 
   for (; endmode == -1 ; ) {
-    agmsg = aguix->GetMessage( win );
+    agmsg = aguix->GetMessage( NULL );
     if ( agmsg != NULL ) {
       switch ( agmsg->type ) {
         case AG_CLOSEWINDOW:
@@ -524,26 +540,29 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
           }
           break;
         case AG_KEYPRESSED:
-          if ( agmsg->key.key == XK_Return && _resultlv->getHasFocus() == true ) {
-            int row = _resultlv->getActiveRow();
-            if ( _resultlv->isValidRow( row ) == true ) {
-              endmode = 2;
-            }
-          } else if ( agmsg->key.key == XK_Return && KEYSTATEMASK( agmsg->key.keystate ) == ControlMask ) {
-              startSearch();
-          } else if ( agmsg->key.key == XK_Escape ) {
-            endmode = 1;
-          } else if ( agmsg->key.key == XK_F3 ) {
-            viewResult();
-          } else if ( agmsg->key.key == XK_F4 ) {
-            editResult();
-          } else if ( agmsg->key.key == XK_BackSpace && _resultlv->getHasFocus() == true ) {
-            removeSelectedResults();
-          } else if ( agmsg->key.key == XK_F5 ) {
-            newSearch();
-          }
-          break;
+	    if ( win->isParent( agmsg->key.window, false ) ) {
+		if ( agmsg->key.key == XK_Return && _resultlv->getHasFocus() == true ) {
+		    int row = _resultlv->getActiveRow();
+		    if ( _resultlv->isValidRow( row ) == true ) {
+			endmode = 2;
+		    }
+		} else if ( agmsg->key.key == XK_Return && KEYSTATEMASK( agmsg->key.keystate ) == ControlMask ) {
+		    startSearch();
+		} else if ( agmsg->key.key == XK_Escape ) {
+		    endmode = 1;
+		} else if ( agmsg->key.key == XK_F3 ) {
+		    viewResult();
+		} else if ( agmsg->key.key == XK_F4 ) {
+		    editResult();
+		} else if ( agmsg->key.key == XK_BackSpace && _resultlv->getHasFocus() == true ) {
+		    removeSelectedResults();
+		} else if ( agmsg->key.key == XK_F5 ) {
+		    newSearch();
+		}
+	    }
+	    break;
       }
+      aguix->executeBGHandlers( *agmsg );
       aguix->ReplyMessage( agmsg );
     } else {
       if ( _sth == NULL || _sth->getCurrentMode() == SearchThread::FINISHED ) {
@@ -840,9 +859,8 @@ SearchOp::ResultStore *SearchOp::getResultStore( int pos, const SearchSettings *
 class DW_SetFollowSymlinks : public NWC::DirWalkCallBack
 {
 public:
-    DW_SetFollowSymlinks( bool follow_symlinks, bool search_vfs, bool search_same_fs ) : _follow_symlinks( follow_symlinks ),
-                                                                                         _search_vfs( search_vfs ),
-                                                                                         _search_same_fs( search_same_fs ) {}
+    DW_SetFollowSymlinks( bool follow_symlinks, bool search_same_fs ) : _follow_symlinks( follow_symlinks ),
+                                                                        _search_same_fs( search_same_fs ) {}
 
   int visit( NWC::File &file, NWC::Dir::WalkControlObj &cobj ) { return 0; }
   int visitEnterDir( NWC::Dir &dir, NWC::Dir::WalkControlObj &cobj )
@@ -851,16 +869,17 @@ public:
 
     try {
       NWC::VirtualDir &vdir = dynamic_cast<NWC::VirtualDir&>( dir );
-      vdir.setSearchVFS( _search_vfs );
       vdir.setSearchSameFS( _search_same_fs );
     } catch ( std::bad_cast ) {
     }
     return 0;
   }
   int visitLeaveDir( NWC::Dir &dir, NWC::Dir::WalkControlObj &cobj ) { return 0; }
+  int prepareDirWalk( const NWC::Dir &dir, NWC::Dir::WalkControlObj &cobj,
+                      std::list< RefCount< NWC::FSEntry > > &return_add_entries,
+                      std::list< RefCount< NWC::FSEntry > > &return_skip_entries ) { return 0; }
 private:
   bool _follow_symlinks;
-  bool _search_vfs;
   bool _search_same_fs;
 };
 
@@ -884,10 +903,9 @@ void SearchOp::startSearch()
   _resultlv->takeFocus();
   
   use_dir->setFollowSymlinks( sets.getFollowSymlinks() );
-  use_dir->setSearchVFS( sets.getSearchVFS() );
   use_dir->setSearchSameFS( sets.getSearchSameFS() );
   
-  DW_SetFollowSymlinks dw1( sets.getFollowSymlinks(), sets.getSearchVFS(), sets.getSearchSameFS() );
+  DW_SetFollowSymlinks dw1( sets.getFollowSymlinks(), sets.getSearchSameFS() );
   use_dir->walk( dw1 );
 
   _sth = new SearchThread( std::auto_ptr<NWC::Dir>( use_dir ) );
@@ -984,6 +1002,7 @@ SearchSettings SearchOp::getCurrentSearchSettings()
   sets.setCheckSizeLEQ( m_size_leq_cb->getState() );
   sets.setSizeGEQ( m_size_geq_sg->getText() );
   sets.setSizeLEQ( m_size_leq_sg->getText() );
+  sets.setMaxVFSDepth( atoi( m_max_vfs_depth_sg->getText() ) );
   return sets;
 }
 
@@ -1020,6 +1039,9 @@ void SearchOp::restoreSearchSettings()
   m_size_leq_cb->setState( sets.getCheckSizeLEQ() );
   m_size_geq_sg->setText( sets.getSizeGEQ().c_str() );
   m_size_leq_sg->setText( sets.getSizeLEQ().c_str() );
+
+  std::string s1 = AGUIXUtils::formatStringToString( "%d", sets.getMaxVFSDepth() );
+  m_max_vfs_depth_sg->setText( s1.c_str() );
 }
 
 void SearchOp::setCurrentResultStore( int pos, const SearchSettings *sets )
@@ -1063,6 +1085,7 @@ void SearchOp::cleanupPtrs()
   m_size_leq_cb = NULL;
   m_size_geq_sg = NULL;
   m_size_leq_sg = NULL;
+  m_max_vfs_depth_sg = NULL;
   m_options_k1 = NULL;
 }
 
@@ -1139,11 +1162,9 @@ void SearchOp::viewResult()
       //TODO check whether file system exceeds basic textstorage size and ask for increase
       l.push_back( r.getFullname() );
 
-      bool old_sln = FileViewer::getShowLineNumbers();
-      FileViewer::setShowLineNumbers( true );
       FileViewer fv;
-      fv.view( l, r.getLineNr(), true );
-      FileViewer::setShowLineNumbers( old_sln );
+      fv.setShowLineNumbers( true );
+      fv.view( l, NULL, r.getLineNr(), true );
     }
   }
 }
