@@ -1,6 +1,6 @@
 /* startprogop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008,2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2008,2010-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -34,6 +34,15 @@
 #include "nmspecialsourceext.hh"
 #include "fileviewer.hh"
 #include "processexitaction.hh"
+#include "datei.h"
+#include "worker_locale.h"
+#include <aguix/fieldlistview.h>
+#include <aguix/cyclebutton.h>
+#include <aguix/choosebutton.h>
+#include <aguix/stringgadget.h>
+#include <aguix/button.h>
+#include "wconfig.h"
+#include "flattypelist.hh"
 
 const char *StartProgOp::name="StartProgOp";
 
@@ -180,7 +189,7 @@ StartProgOp::normalmodestartprog( ActionMessage *am )
 
       std::string tmpoutput_lnk;
 
-      RefCount< GenericCallback< void > > pea( NULL );
+      RefCount< GenericCallbackArg< void, int > > pea( NULL );
       
       if ( m1->_start == STARTPROGOP_SHOW_OUTPUT_INT ) {
           tmpoutput_lnk = Datei::createTMPHardlink( tmpoutput );
@@ -255,7 +264,7 @@ StartProgOp::normalmodestartprog( ActionMessage *am )
         worker_unlink( tmpoutput );
 
         if ( pea.getVal() != NULL ) {
-            pea->callback();
+            pea->callback( 0 );
         }
       }
     } else {
