@@ -1,6 +1,6 @@
 /* volumemanagerui.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009-2010 Ralf Hoffmann.
+ * Copyright (C) 2009-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -34,12 +34,16 @@
 #include "worker.h"
 #include "pers_string_list.hh"
 #include <aguix/textview.h>
+#include <aguix/popupmenu.hh>
+#include "worker_locale.h"
 
 VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_aguix( aguix ),
                                                                            m_hwman( hwman ),
                                                                            m_status_info( "",
                                                                                           RefCount<AWidth>( new AFontWidth( &aguix,
-                                                                                                                            NULL ) ) )
+                                                                                                                            NULL ) ) ),
+									   m_eject_menu( NULL ),
+									   m_menu_command( VOLMANUI_MENU_EJECT )
 {
     std::string cfgfile = getHiddenDevicesFile();
     m_hide_entries = std::auto_ptr< PersistentStringList >( new PersistentStringList( cfgfile ) );
@@ -76,7 +80,7 @@ VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_agu
     m_lv->setDisplayFocus( true );
     m_lv->setGlobalFieldSpace( 5 );
 
-    AContainer *cont4 = m_cont2->add( new AContainer( m_win.get(), 1, 4 ), 1, 0 );
+    AContainer *cont4 = m_cont2->add( new AContainer( m_win.get(), 1, 6 ), 1, 0 );
     cont4->setBorderWidth( 0 );
     cont4->setMinSpace( 5 );
     cont4->setMaxSpace( 5 );
@@ -85,6 +89,20 @@ VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_agu
                                                   0, 0, AContainer::CO_FIX ) );
     m_unmountb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0, catalog.getLocale( 886 ), 1, 0, 0 ),
                                                      0, 1, AContainer::CO_FIX ) );
+    m_ejectb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0,
+                                                              catalog.getLocale( 920 ),
+                                                              catalog.getLocale( 929 ),
+                                                              1, 1,
+                                                              0, 0,
+                                                              0 ),
+                                                  0, 2, AContainer::CO_FIX ) );
+    m_closetrayb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0,
+                                                                  catalog.getLocale( 921 ),
+                                                                  catalog.getLocale( 930 ),
+                                                                  1, 1,
+                                                                  0, 0,
+                                                                  0 ),
+						      0, 3, AContainer::CO_FIX ) );
     m_hideb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix,
                                                              0, 0,
                                                              catalog.getLocale( 887 ),
@@ -92,7 +110,9 @@ VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_agu
                                                              1, 1,
                                                              0, 0,
                                                              0 ),
-                                                 0, 2, AContainer::CO_FIX ) );
+                                                 0, 4, AContainer::CO_FIX ) );
+    m_updateb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0, catalog.getLocale( 922 ), 1, 0, 0 ),
+						   0, 5, AContainer::CO_FIX ) );
     AContainer *cont7 = cont0->add( new AContainer( m_win.get(), 2, 1 ), 0, 2 );
     cont7->setBorderWidth( 0 );
     cont7->setMinSpace( 5 );
@@ -131,6 +151,9 @@ VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_agu
 
 VolumeManagerUI::~VolumeManagerUI()
 {
+    if ( m_eject_menu != NULL ) {
+	delete m_eject_menu;
+    }
 }
 
 int VolumeManagerUI::mainLoop()
@@ -195,6 +218,21 @@ int VolumeManagerUI::mainLoop()
                       mountRow( m_lv->getActiveRow() );
                   } else if ( msg->button.button == m_unmountb ) {
                       unmountRow( m_lv->getActiveRow() );
+                  } else if ( msg->button.button == m_ejectb ) {
+                      if ( msg->button.state == 2 ) {
+                          buildEjectMenu( VOLMANUI_MENU_EJECT );
+                      } else {
+                          ejectOrCloseTray( VOLMANUI_MENU_EJECT );
+                      }
+                  } else if ( msg->button.button == m_closetrayb ) {
+                      if ( msg->button.state == 2 ) {
+                          buildEjectMenu( VOLMANUI_MENU_CLOSETRAY );
+                      } else {
+                          ejectOrCloseTray( VOLMANUI_MENU_CLOSETRAY );
+                      }
+                  } else if ( msg->button.button == m_updateb ) {
+		      updateLV();
+		      maximizeWin();
                   } else if ( msg->button.button == m_hideb ) {
                       if ( msg->button.state == 2 ) {
                           editHideList();
@@ -259,6 +297,11 @@ int VolumeManagerUI::mainLoop()
                     }
                     break;
 #endif
+		case AG_POPUPMENU_CLICKED:
+		    if ( msg->popupmenu.menu == m_eject_menu ) {
+			handlePopupMsg( msg );
+		    }
+		    break;
             }
             m_aguix.ReplyMessage( msg );
         }
@@ -580,3 +623,213 @@ std::list< std::string > VolumeManagerUI::getListOfHiddenDevices()
     PersistentStringList psl( getHiddenDevicesFile() );
     return psl.getList();
 }
+
+void VolumeManagerUI::buildEjectMenu( const menu_command_t &menu_command )
+{
+    if ( m_eject_menu != NULL ) {
+	delete m_eject_menu;
+	m_eject_menu = NULL;
+    }
+
+    m_menu_command = menu_command;
+    std::list< HWVolume > l = m_hwman.getEjectableDevices();
+    l.sort( hwvolume_cmpf() );
+
+    m_ejectable_devices.clear();
+    for ( std::list< HWVolume >::iterator it1 = l.begin();
+	  it1 != l.end();
+	  it1++ ) {
+	if ( ! m_hide_entries->contains( it1->getDevice() ) ) {
+	    m_ejectable_devices.push_back( *it1 );
+	}
+    }
+
+    if ( m_ejectable_devices.size() < 1 ) {
+        m_status_info.setContent( catalog.getLocale( 934 ) );
+        m_status_tv->textStorageChanged();
+        m_aguix.Flush();
+        return;
+    }
+
+    if ( m_ejectable_devices.size() == 1 ) {
+	// only one device, directly eject/closetray
+	if ( m_menu_command == VOLMANUI_MENU_EJECT ) {
+	    eject( *( m_ejectable_devices.begin() ) );
+	} else {
+	    closeTray( *( m_ejectable_devices.begin() ) );
+	}
+	return;
+    }
+
+    std::list<PopUpMenu::PopUpEntry> m1;
+    PopUpMenu::PopUpEntry e1;
+    if ( m_menu_command == VOLMANUI_MENU_EJECT ) {
+	e1.name = catalog.getLocale( 920 );
+    } else {
+	e1.name = catalog.getLocale( 921 );
+    }
+    e1.type = PopUpMenu::HEADER;
+    m1.push_back( e1 );
+    e1.type = PopUpMenu::HLINE;
+    m1.push_back( e1 );
+
+    int pos = 0;
+    for ( std::list< HWVolume >::iterator it1 = m_ejectable_devices.begin();
+	  it1 != m_ejectable_devices.end();
+	  it1++, pos++ ) {
+	e1.type = PopUpMenu::NORMAL;
+
+        std::string descr = m_hwman.getDescription( *it1 );
+
+        if ( ! descr.empty() ) {
+            descr += " (";
+            descr += it1->getDevice();
+            descr += ")";
+        } else {
+            descr = it1->getDevice();
+        }
+
+	e1.name = descr;
+	e1.id = pos;
+	m1.push_back( e1 );
+    }
+
+    m_eject_menu = new PopUpMenu( &m_aguix, m1 );
+    m_eject_menu->create();
+    m_eject_menu->show();
+}
+
+void VolumeManagerUI::closeEjectMenu()
+{
+    if ( m_eject_menu != NULL ) {
+	delete m_eject_menu;
+	m_eject_menu = NULL;
+    }
+}
+
+void VolumeManagerUI::handlePopupMsg( AGMessage *msg )
+{
+    if ( msg->popupmenu.menu != m_eject_menu ) return;
+
+    int pos = msg->popupmenu.clicked_entry_id;
+    
+    if ( pos >= 0 && pos < (int)m_ejectable_devices.size() ) {
+	std::list< HWVolume >::iterator it1 = m_ejectable_devices.begin();
+
+	while ( pos > 0 ) {
+	    if ( it1 == m_ejectable_devices.end() ) {
+		break;
+	    }
+
+	    it1++;
+	    pos--;
+	}
+
+	if ( it1 != m_ejectable_devices.end() ) {
+	    if ( m_menu_command == VOLMANUI_MENU_EJECT ) {
+		eject( *it1 );
+	    } else {
+		closeTray( *it1 );
+	    }
+	}
+    }
+}
+
+void VolumeManagerUI::eject( HWVolume &vol )
+{
+    m_win->setCursor( AGUIX::WAIT_CURSOR );
+    m_status_info.setContent( catalog.getLocale( 918 ) );
+    m_status_tv->textStorageChanged();
+    m_aguix.Flush();
+    
+    std::string error;
+    
+    if ( m_hwman.eject( vol, error ) == 0 ) {
+	m_status_info.setContent( catalog.getLocale( 919 ) );
+    } else {
+	m_status_info.setContent( error );
+    }
+    m_status_tv->textStorageChanged();
+    
+    m_win->unsetCursor();
+
+    updateLV();
+    maximizeWin();
+
+    m_last_device = vol.getDevice();
+}
+
+void VolumeManagerUI::closeTray( HWVolume &vol )
+{
+    m_win->setCursor( AGUIX::WAIT_CURSOR );
+    m_status_info.setContent( catalog.getLocale( 916 ) );
+    m_status_tv->textStorageChanged();
+    m_aguix.Flush();
+    
+    std::string error;
+    
+    if ( m_hwman.closeTray( vol, error ) == 0 ) {
+	m_status_info.setContent( catalog.getLocale( 917 ) );
+    } else {
+	m_status_info.setContent( error );
+    }
+    m_status_tv->textStorageChanged();
+    
+    m_win->unsetCursor();
+
+    updateLV();
+    maximizeWin();
+
+    m_last_device = vol.getDevice();
+}
+
+void VolumeManagerUI::ejectOrCloseTray( const menu_command_t &menu_command )
+{
+    std::list< HWVolume > l = m_hwman.getEjectableDevices();
+    std::string dev;
+
+    if ( m_lv->isValidRow( m_lv->getActiveRow() ) ) {
+        dev = m_lv->getText( m_lv->getActiveRow(), 1 );
+    } else {
+        dev = m_last_device;
+    }
+
+    std::list< HWVolume >::iterator it1 = l.end();
+
+    if ( ! dev.empty() ) {
+        for ( it1 = l.begin();
+              it1 != l.end();
+              it1++ ) {
+	    if ( ! m_hide_entries->contains( it1->getDevice() ) ) {
+		if ( it1->getDevice() == dev ) break;
+	    }
+        }
+    }
+
+    if ( it1 == l.end() &&
+         ! m_last_device.empty() ) {
+        dev = m_last_device;
+
+        for ( it1 = l.begin();
+              it1 != l.end();
+              it1++ ) {
+            if ( it1->getDevice() == dev ) break;
+        }
+    }
+
+    if ( it1 != l.end() ) {
+        if ( menu_command == VOLMANUI_MENU_EJECT ) {
+            eject( *it1 );
+        } else {
+            closeTray( *it1 );
+        }
+    } else {
+        if ( menu_command == VOLMANUI_MENU_EJECT ) {
+            m_status_info.setContent( catalog.getLocale( 931 ) );
+        } else {
+            m_status_info.setContent( catalog.getLocale( 932 ) );
+        }
+        m_status_tv->textStorageChanged();
+        buildEjectMenu( menu_command );
+    }
+}
