@@ -1,6 +1,6 @@
 /* wconfig.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -23,23 +23,12 @@
 #define WCONFIG_H
 
 #include "wdefines.h"
-#include <aguix/aguix.h>
-#include <aguix/awindow.h>
-#include <aguix/stringgadget.h>
-#include <aguix/bevelbox.h>
-#include <aguix/fieldlistview.h>
-#include <aguix/solidbutton.h>
-#include <aguix/choosebutton.h>
-#include <aguix/cyclebutton.h>
-#include "worker_locale.h"
-#include "functionproto.h"
-#include "datei.h"
 #include "worker_types.h"
 #include <vector>
 #include <list>
-#include "flattypelist.hh"
-#include "wckey.hh"
+#include <map>
 #include "layoutsettings.hh"
+#include <aguix/aguix.h>
 
 class Worker;
 class WCPath;
@@ -48,6 +37,10 @@ class WCButton;
 class WCFiletype;
 class WC_Color;
 class WCDoubleShortkey;
+class FunctionProto;
+class Datei;
+class FlatTypeList;
+class List;
 
 class WConfig
 {
@@ -111,7 +104,7 @@ public:
   void setStartDir(int,const char*);
   char *getStartDir(int);
   void setFont(int,const char*);
-  char *getFont(int);
+  std::string getFont( int );
   void setPaths(List*);
   List *getPaths();
   void setFiletypes(List*);
@@ -308,15 +301,20 @@ public:
   void setSaveWorkerStateOnExit( bool nv );
   bool getSaveWorkerStateOnExit() const;
 
+  void setUseVersionStringCompare( bool nv );
+  bool getUseVersionStringCompare() const;
+
   typedef enum {
       FONT_X11_GLOBAL,
       FONT_X11_BUTTONS,
       FONT_X11_LEFT,
       FONT_X11_RIGHT,
+      FONT_X11_TEXTVIEW,
       FONT_XFT_GLOBAL,
       FONT_XFT_BUTTONS,
       FONT_XFT_LEFT,
-      FONT_XFT_RIGHT
+      FONT_XFT_RIGHT,
+      FONT_XFT_TEXTVIEW
   } font_type_t;
 
   void setFontName( font_type_t fonttype, const std::string &name );
@@ -334,6 +332,10 @@ public:
     std::string getVMPartitionFile() const;
     void setVMRequestAction( bool nv );
     bool getVMRequestAction() const;
+    void setVMEjectCommand( const std::string &cmd );
+    std::string getVMEjectCommand() const;
+    void setVMCloseTrayCommand( const std::string &cmd );
+    std::string getVMCloseTrayCommand() const;
 protected:
   char *lang;
   unsigned int rows,columns;
@@ -359,7 +361,6 @@ protected:
   int request[2];
   int lvheader[2];
   char *dir[2];  // left=0, right=1
-  char *fonts[4];  // global, buttons, left lister, right lister
   List *paths;  // Elemente sind WCPath
   List *filetypes; // Elemente sind WCFiletype
   List *hotkeys; // Elemente sind WCHotkey
@@ -487,7 +488,11 @@ protected:
         std::string mtab_file;
         std::string part_file;
         bool request_action;
+        std::string eject_command;
+        std::string closetray_command;
     } m_vm_settings;
+
+    bool m_use_version_string_compare;
 };
 
 extern WConfig *wconfig;
