@@ -1,6 +1,6 @@
 /* wconfig_bookmarkcolor.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2008 Ralf Hoffmann.
+ * Copyright (C) 2008,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -22,6 +22,11 @@
 #include "wconfig_bookmarkcolor.hh"
 #include "wconfig.h"
 #include "worker.h"
+#include "worker_locale.h"
+#include <aguix/bevelbox.h>
+#include <aguix/fieldlistview.h>
+#include <aguix/button.h>
+#include <aguix/stringgadget.h>
 
 BookmarkColorPanel::BookmarkColorPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
