@@ -1,6 +1,6 @@
 /* wconfig_buttongrpconf.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2006,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -22,6 +22,8 @@
 #include "wconfig_buttongrpconf.hh"
 #include "wconfig.h"
 #include "worker.h"
+#include "worker_locale.h"
+#include <aguix/stringgadget.h>
 
 ButtonGrpConfPanel::ButtonGrpConfPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
