@@ -1,6 +1,6 @@
 /* wconfig_font.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2006,2010-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -22,6 +22,9 @@
 #include "wconfig_font.hh"
 #include "wconfig.h"
 #include "worker.h"
+#include "worker_locale.h"
+#include "fontreq.h"
+#include <aguix/button.h>
 
 FontPanel::FontPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
@@ -39,7 +42,7 @@ int FontPanel::create()
   
   res = Panel::create();
 
-  ac1 = setContainer( new AContainer( this, 1, 9 ), true );
+  ac1 = setContainer( new AContainer( this, 1, 11 ), true );
   ac1->setBorderWidth( 5 );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
@@ -53,33 +56,41 @@ int FontPanel::create()
                              0, 1, AContainer::CO_INCW );
   bs[0]->connect( this );
   
-  ts[0] = (Text*)ac1->add( new Text( _aguix, 0, 0, _baseconfig.getFont( 0 ), 1 ),
+  ts[0] = (Text*)ac1->add( new Text( _aguix, 0, 0, _baseconfig.getFont( 0 ).c_str(), 1 ),
                            0, 2, AContainer::CO_INCW );
-  ts[0]->setFont( _baseconfig.getFont( 0 ) );
+  ts[0]->setFont( _baseconfig.getFont( 0 ).c_str() );
 
   bs[1] = (Button*)ac1->add( new Button( _aguix, 0, 0, catalog.getLocale( 242 ), 1, 0, 0 ),
                              0, 3, AContainer::CO_INCW );
   bs[1]->connect( this );
 
-  ts[1] = (Text*)ac1->add( new Text( _aguix, 0, 0, _baseconfig.getFont( 1 ), 1 ),
+  ts[1] = (Text*)ac1->add( new Text( _aguix, 0, 0, _baseconfig.getFont( 1 ).c_str(), 1 ),
                            0, 4, AContainer::CO_INCW );
-  ts[1]->setFont( _baseconfig.getFont( 1 ) );
+  ts[1]->setFont( _baseconfig.getFont( 1 ).c_str() );
   
   bs[2] = (Button*)ac1->add( new Button( _aguix, 0, 0, catalog.getLocale( 243 ), 1, 0, 0 ),
                              0, 5, AContainer::CO_INCW );
   bs[2]->connect( this );
   
-  ts[2] = (Text*)ac1->add( new Text( _aguix, 0, 0, _baseconfig.getFont( 2 ), 1 ),
+  ts[2] = (Text*)ac1->add( new Text( _aguix, 0, 0, _baseconfig.getFont( 2 ).c_str(), 1 ),
                            0, 6, AContainer::CO_INCW );
-  ts[2]->setFont( _baseconfig.getFont( 2 ) );
+  ts[2]->setFont( _baseconfig.getFont( 2 ).c_str() );
 
   bs[3] = (Button*)ac1->add( new Button( _aguix, 0, 0, catalog.getLocale( 244 ), 1, 0, 0 ),
                              0, 7, AContainer::CO_INCW );
   bs[3]->connect( this );
 
-  ts[3] = (Text*)ac1->add( new Text( _aguix, 0, 0, _baseconfig.getFont( 3 ), 1 ),
+  ts[3] = (Text*)ac1->add( new Text( _aguix, 0, 0, _baseconfig.getFont( 3 ).c_str(), 1 ),
                            0, 8, AContainer::CO_INCW );
-  ts[3]->setFont( _baseconfig.getFont( 3 ) );
+  ts[3]->setFont( _baseconfig.getFont( 3 ).c_str() );
+
+  bs[4] = (Button*)ac1->add( new Button( _aguix, 0, 0, catalog.getLocale( 915 ), 1, 0, 0 ),
+                             0, 9, AContainer::CO_INCW );
+  bs[4]->connect( this );
+
+  ts[4] = (Text*)ac1->add( new Text( _aguix, 0, 0, _baseconfig.getFont( 4 ).c_str(), 1 ),
+                           0, 10, AContainer::CO_INCW );
+  ts[4]->setFont( _baseconfig.getFont( 4 ).c_str() );
 
   ac1->readLimits();
   contMaximize( true );
@@ -92,6 +103,7 @@ int FontPanel::saveValues()
   _baseconfig.setFont( 1, ts[1]->getText() );
   _baseconfig.setFont( 2, ts[2]->getText() );
   _baseconfig.setFont( 3, ts[3]->getText() );
+  _baseconfig.setFont( 4, ts[4]->getText() );
   return 0;
 }
 
@@ -101,7 +113,7 @@ void FontPanel::run( Widget *elem, AGMessage &msg )
   char *tstr;
 
   if ( msg.type == AG_BUTTONCLICKED ) {
-    for ( i = 0; i < 4; i++ ) {
+    for ( i = 0; i < 5; i++ ) {
       if ( msg.button.button == bs[i] ) {
         tstr = NULL;
         erg = freq->request( ts[i]->getText(), &tstr );
