@@ -1,6 +1,6 @@
 /* wconfig_lang.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006,2009-2010 Ralf Hoffmann.
+ * Copyright (C) 2006,2009-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,6 +25,8 @@
 #include <aguix/utf8.hh>
 #include "workerinitialsettings.hh"
 #include "nwc_path.hh"
+#include "worker_locale.h"
+#include <aguix/fieldlistview.h>
 
 LangPanel::LangPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
