@@ -1,6 +1,6 @@
 /* wconfig_layout.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006,2009 Ralf Hoffmann.
+ * Copyright (C) 2006,2009,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,7 +25,12 @@
 #include <aguix/acontainerbb.h>
 #include <algorithm>
 #include <aguix/slider.h>
+#include <aguix/choosebutton.h>
+#include <aguix/solidbutton.h>
+#include <aguix/fieldlistview.h>
+#include <aguix/button.h>
 #include <sstream>
+#include "worker_locale.h"
 
 static struct {
   LayoutSettings::layoutID_t id;
