@@ -1,6 +1,6 @@
 /* wconfig_mouse.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006-2007 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2006-2007,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -23,6 +23,8 @@
 #include "wconfig.h"
 #include "worker.h"
 #include <aguix/acontainerbb.h>
+#include <aguix/cyclebutton.h>
+#include "worker_locale.h"
 
 MousePanel::MousePanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
