@@ -1,6 +1,6 @@
 /* wconfig_path.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2006,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -23,6 +23,11 @@
 #include "wconfig.h"
 #include "wcpath.hh"
 #include "worker.h"
+#include "worker_locale.h"
+#include <aguix/button.h>
+#include <aguix/solidbutton.h>
+#include <aguix/cyclebutton.h>
+#include "simplelist.hh"
 
 PathPanel::PathPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
