@@ -1,6 +1,6 @@
 /* wconfig_termconf.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2006,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -22,6 +22,9 @@
 #include "wconfig_termconf.hh"
 #include "wconfig.h"
 #include "worker.h"
+#include "worker_locale.h"
+#include <aguix/button.h>
+#include <aguix/stringgadget.h>
 
 TermConfPanel::TermConfPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
