@@ -1,6 +1,6 @@
 /* wconfig_time.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2006,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -23,6 +23,10 @@
 #include "wconfig.h"
 #include "worker.h"
 #include <aguix/acontainerbb.h>
+#include <aguix/cyclebutton.h>
+#include <aguix/choosebutton.h>
+#include <aguix/stringgadget.h>
+#include "worker_locale.h"
 
 TimePanel::TimePanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
