@@ -1,6 +1,6 @@
 /* worker.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -23,24 +23,16 @@
 #define WORKER_H
 
 #include "wdefines.h"
-#include <aguix/lowlevelfunc.h>
-#include <aguix/aguix.h>
-#include <aguix/util.h>
-#include <aguix/message.h>
-#include <aguix/button.h>
-#include <aguix/solidbutton.h>
-#include <aguix/request.h>
 #include "functionproto.h"
-#include "wconfig.h"
-#include "dnd.h"
-#include "partspace.h"
-#include <aguix/acontainer.h>
 #include <string>
 #include "generic_callback.hh"
 #include "layoutsettings.hh"
 #include "timedtext.hh"
-#include "hw_volume_manager.hh"
 #include "processhandler.hh"
+#include <map>
+#include <aguix/message.h>
+#include "hw_volume_manager.hh"
+#include <memory>
 
 class ListerMode;
 class Lister;
@@ -50,6 +42,14 @@ class HWVolume;
 class WaitThread;
 class TimeoutStore;
 class EventQueue;
+class Requester;
+class Button;
+class AWindow;
+class AContainer;
+class WCHotkey;
+class WCButton;
+class WCPath;
+class PartSpace;
 
 class Worker
 {
@@ -95,7 +95,6 @@ public:
   std::string PS_getFreeSpaceH() const;
   std::string PS_getSpaceH() const;
   void PS_setLifetime( double t );
-  void showLicense();
   void setWaitCursor();
   void unsetWaitCursor();
   static const std::string getDataDir();
@@ -104,7 +103,7 @@ public:
 		  const char *tmpname,
 		  const char *tmpoutput,
 		  bool inbackground,
-                  RefCount< GenericCallback< void > > pea = RefCount< GenericCallback< void > >( NULL ) );
+                  RefCount< GenericCallbackArg< void, int > > pea );
 
   static std::string getWorkerConfigDir();
 
@@ -133,12 +132,19 @@ public:
     void registerTimeout( loff_t timeout_ms );
     void unregisterTimeout( loff_t timeout_ms );
     void wakeupMainLoop();
+
+    void showCommandFailed( int status );
+
+    void setIgnoreKey( KeySym key, bool state );
+    bool isIgnoredKey( KeySym key ) const;
+
+    void shuffleButton( int dir );
+    void switchToButtonBank( int nr );
  protected:
   void createMainWin();
   void setupMainWin();
   void closeMainWin();
   void shufflePath();
-  void shuffleButton( int dir );
   void shuffleButton( int dir, bool nocycle );
   void about();
   bool configure();
@@ -179,7 +185,7 @@ public:
 
   static Requester *req_static;
   
-  static int shortkeysort(void*p1,void*p2);
+    static int shortkeysort( void *p1, void *p2, int sortmode );
   struct shortkeylisttype {WCHotkey *h;
                            WCButton *b;
                            WCPath *p;};
@@ -278,6 +284,13 @@ public:
         worker_event_store() : check_children( false ) {}
         bool check_children;
     } m_event_store;
+
+    int buildShortkeyLV( FieldListView *lv,
+                         List *sklist );
+
+    std::map< KeySym, int > m_ignored_keys;
+
+    void updateSettingsFromWConfig();
 };
 
 #endif
