@@ -1,6 +1,6 @@
 /* worker_locale.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,9 +25,10 @@
 #include <aguix/utf8.hh>
 #include "workerinitialsettings.hh"
 #include "nwc_path.hh"
+#include "datei.h"
 
-#define CATENTRY 915
-#define CATCOMENTRY 59
+#define CATENTRY 962
+#define CATCOMENTRY 60
 #define CATFLAGENTRY 59
 
 WorkerLocale catalog;
@@ -1016,6 +1017,53 @@ match any font." );
   catalog[912]=dupstring( "Volume label" );
   catalog[913]=dupstring( "Volume size" );
   catalog[914]=dupstring( "Size (human readable)" );
+  catalog[915]=dupstring( "Text view font" );
+  catalog[916]=dupstring( "Closing tray..." );
+  catalog[917]=dupstring( "Closing tray successful" );
+  catalog[918]=dupstring( "Ejecting..." );
+  catalog[919]=dupstring( "Eject successful" );
+  catalog[920]=dupstring( "Eject" );
+  catalog[921]=dupstring( "Close tray" );
+  catalog[922]=dupstring( "Update list" );
+  catalog[923]=dupstring( "Eject: Can't eject non-HAL device with HAL" );
+  catalog[924]=dupstring( "Close tray: Can't close tray of non-HAL device with HAL" );
+  catalog[925]=dupstring( "Eject failed: %s: %s" );
+  catalog[926]=dupstring( "Close tray failed: %s: %s" );
+  catalog[927]=dupstring( "Command to eject non-HAL devices:" );
+  catalog[928]=dupstring( "Command to close tray of non-HAL devices:" );
+  catalog[929]=dupstring( "Eject (from menu)" );
+  catalog[930]=dupstring( "Close tray (from menu)" );
+  catalog[931]=dupstring( "Don't know what device to eject, choose from menu" );
+  catalog[932]=dupstring( "Don't know what device to close tray for, choose from menu" );
+  catalog[933]=dupstring( "AVFS module:" );
+  catalog[934]=dupstring( "No device found for opening/closing." );
+  catalog[935]=dupstring( "Key %d" );
+  catalog[936]=dupstring( "Type of shortkey" );
+  catalog[937]=dupstring( "Name of shortkey" );
+  catalog[938]=dupstring( "Because of length limitations the following command string couldn't be built. Not all file names could be inserted for the chosen flags but you can decide to continue with as many files replaced as possible.\n\n" );
+  catalog[939]=dupstring( "Text view mode" );
+  catalog[940]=dupstring( "Maximum VFS depth:" );
+  catalog[941]=dupstring( "External command exited with code %d" );
+  catalog[942]=dupstring( "File type" );
+  catalog[943]=dupstring( "Cursor" );
+  catalog[944]=dupstring( "File list" );
+  catalog[945]=dupstring( "File operations" );
+  catalog[946]=dupstring( "Selections" );
+  catalog[947]=dupstring( "Settings" );
+  catalog[948]=dupstring( "Scripting" );
+  catalog[949]=dupstring( "Other" );
+  catalog[950]=dupstring( "Category" );
+  catalog[951]=dupstring( "Command name" );
+  catalog[952]=dupstring( "Close tab" );
+  catalog[953]=dupstring( "Tab to other side" );
+  catalog[954]=dupstring( "Tab to other side as new tab" );
+  catalog[955]=dupstring( "Use flexible matching" );
+  catalog[956]=dupstring( "Use version string compare" );
+  catalog[957]=dupstring( "Switch mode:" );
+  catalog[958]=dupstring( "Switch to next bank" );
+  catalog[959]=dupstring( "Switch to prev bank" );
+  catalog[960]=dupstring( "Switch to bank number" );
+  catalog[961]=dupstring( "Bank number:" );
 
 //  catalog[]=dupstring( "" );
   
@@ -1078,6 +1126,7 @@ match any font." );
   catalogcom[56]=dupstring( "Modify tabs" );
   catalogcom[57]=dupstring( "Change layout" );
   catalogcom[58]=dupstring( "Volume manager" );
+  catalogcom[59]=dupstring( "Switch button bank" );
   
   catalogflag[0]=dupstring( "String requester" );
   catalogflag[1]=dupstring( "path" );
