@@ -1,6 +1,6 @@
 /* wpucontext.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2005,2008 Ralf Hoffmann.
+ * Copyright (C) 2002-2005,2008,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,6 +24,13 @@
 #include "normalmode.h"
 #include "execlass.h"
 #include "nmextlist.hh"
+#include "simplelist.hh"
+#include "worker.h"
+#include "dnd.h"
+#include "worker_locale.h"
+#include <aguix/solidbutton.h>
+#include <aguix/button.h>
+#include "datei.h"
 
 WPUStack::WPUStack()
 {
@@ -384,21 +391,23 @@ int WPUContext::closeWin()
   return 0;
 }
 
-char *WPUContext::parse( const char *str1, int maxlen, bool quote )
+NormalMode::parse_com_str_t WPUContext::parse( const char *str1, std::string &return_str, int maxlen, bool quote )
 {
-  char *tstr = NULL;
-  NormalMode *nm;
+    NormalMode::parse_com_str_t res = NormalMode::PARSE_ERROR;
+    NormalMode *nm;
   
-  if ( worker != NULL ) {
-    buildExtList();
-    if ( activemode != NULL ) {
-      if ( activemode->isType( "NormalMode" ) == true ) {
-        nm = (NormalMode*)activemode;
-        tstr = nm->parseComStrExt( str1, &extorder, maxlen, extlist, quote );
-      }
+    if ( worker != NULL ) {
+        buildExtList();
+        if ( activemode != NULL ) {
+            if ( activemode->isType( "NormalMode" ) == true ) {
+                nm = (NormalMode*)activemode;
+
+                res = nm->parseComStrExt( str1, &extorder, maxlen, extlist,
+                                          quote, return_str);
+            }
+        }
     }
-  }
-  return tstr;
+    return res;
 }
 
 int WPUContext::ifp_lookup( const char *s )
@@ -752,7 +761,7 @@ struct WPUContext::ifp_erg *WPUContext::ifp_factor()
 {
   struct ifp_erg *e = NULL;
   int tnum;
-  char *tstr, *tstr2;
+  char *tstr;
   int exeerror;
 
   switch ( lookahead ) {
@@ -862,9 +871,15 @@ struct WPUContext::ifp_erg *WPUContext::ifp_factor()
       if ( tstr != NULL ) {
         if ( ignore == 0 ) {
           /*execute tstr */
-          tstr2 = parse( tstr, a_max( EXE_STRING_LEN - 1024, 256 ) );
-          _freesafe( tstr );
-          tstr = tstr2;
+          std::string res_str;
+
+          if ( parse( tstr, res_str, a_max( EXE_STRING_LEN - 1024, 256 ) ) == NormalMode::PARSE_SUCCESS ) {
+              _freesafe( tstr );
+              tstr = dupstring( res_str.c_str() );
+          } else {
+              _freesafe( tstr );
+              tstr = NULL;
+          }
   
           if ( tstr != NULL ) {
             e = (struct ifp_erg*)_allocsafe( sizeof( struct ifp_erg ) );
@@ -922,9 +937,15 @@ struct WPUContext::ifp_erg *WPUContext::ifp_factor()
       tstr = readBrace();
       if ( tstr != NULL ) {
         if ( ignore == 0 ) {
-          tstr2 = parse( tstr, a_max( EXE_STRING_LEN - 1024, 256 ) );
-          _freesafe( tstr );
-          tstr = tstr2;
+          std::string res_str;
+
+          if ( parse( tstr, res_str, a_max( EXE_STRING_LEN - 1024, 256 ) ) == NormalMode::PARSE_SUCCESS ) {
+              _freesafe( tstr );
+              tstr = dupstring( res_str.c_str() );
+          } else {
+              _freesafe( tstr );
+              tstr = NULL;
+          }
   
           if ( tstr != NULL ) {
             e = (struct ifp_erg*)_allocsafe( sizeof( struct ifp_erg ) );
@@ -986,8 +1007,13 @@ struct WPUContext::ifp_erg *WPUContext::ifp_factor()
       if ( ignore == 1 ) {
         e->strval = dupstring( "0" );
       } else {
-        e->strval = parse( ifp_lexbuf, a_max( EXE_STRING_LEN - 1024, 256 ), false );
-        if ( e->strval == NULL ) e->strval = dupstring( "0" );
+          std::string res_str;
+
+          if ( parse( ifp_lexbuf, res_str, a_max( EXE_STRING_LEN - 1024, 256 ), false ) == NormalMode::PARSE_SUCCESS ) {
+              e->strval = dupstring( res_str.c_str() );
+          } else {
+              e->strval = dupstring( "0" );
+          }
       }
       e->numval = atoi( e->strval );
       if ( ifp_match( IFP_STRING ) ) {
